@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 extensions = [
     'sphinx.ext.autodoc',
     'jaraco.packaging.sphinx',
@@ -25,8 +27,12 @@ link_files = {
                 url='https://peps.python.org/pep-{pep_number:0>4}/',
             ),
             dict(
-                pattern=r'(python/cpython#|Python #|bpo-)(?P<python>\d+)',
-                url='http://bugs.python.org/issue{python}',
+                pattern=r'(python/cpython#|Python #)(?P<python>\d+)',
+                url='https://github.com/python/cpython/issues/{python}',
+            ),
+            dict(
+                pattern=r'bpo-(?P<bpo>\d+)',
+                url='http://bugs.python.org/issue{bpo}',
             ),
         ],
     ),
@@ -34,7 +40,7 @@ link_files = {
 
 # Be strict about any broken references
 nitpicky = True
-nitpick_ignore = []
+nitpick_ignore: list[tuple[str, str]] = []
 
 # Include Python intersphinx mapping to prevent failures
 # jaraco/skeleton#51
@@ -46,6 +52,17 @@ intersphinx_mapping = {
 # Preserve authored syntax for defaults
 autodoc_preserve_defaults = True
 
+# Add support for linking usernames, PyPI projects, Wikipedia pages
+github_url = 'https://github.com/'
+extlinks = {
+    'user': (f'{github_url}%s', '@%s'),
+    'pypi': ('https://pypi.org/project/%s', '%s'),
+    'wiki': ('https://wikipedia.org/wiki/%s', '%s'),
+}
+extensions += ['sphinx.ext.extlinks']
+
+# local
+
 extensions += ['jaraco.tidelift']
 
 nitpick_ignore.extend([
